@@ -11,11 +11,11 @@ TAP::Parser::Iterator - Base class for TAP source iterators
 
 =head1 VERSION
 
-Version 3.49_02
+Version 3.51_01
 
 =cut
 
-our $VERSION = '3.49_02';
+our $VERSION = '3.51_01';
 
 =head1 SYNOPSIS
 
@@ -61,6 +61,8 @@ Iterate raw input without applying any fixes for quirky input syntax.
 
 =cut
 
+if ( $^O eq 'VMS' ) {
+    eval <<'END' ;
 sub next {
     my $self = shift;
     my $line = $self->next_raw;
@@ -75,6 +77,11 @@ sub next {
 
     return $line;
 }
+END
+}
+else {
+    eval 'sub next { shift->next_raw(@_) }';
+}
 
 sub next_raw {
     require Carp;
@@ -125,17 +132,8 @@ Return the C<exit> status for this iterator.
 
 =cut
 
-sub wait {
-    require Carp;
-    my $msg = Carp::longmess('abstract method called directly!');
-    $_[0]->_croak($msg);
-}
-
-sub exit {
-    require Carp;
-    my $msg = Carp::longmess('abstract method called directly!');
-    $_[0]->_croak($msg);
-}
+#can not call abstract base method, next_raw is a fatal stub
+*exit = *wait = *next_raw;
 
 1;
 
