@@ -21,11 +21,11 @@ TAP::Parser::SourceHandler::Perl - Stream TAP from a Perl executable
 
 =head1 VERSION
 
-Version 3.49_02
+Version 3.51_01
 
 =cut
 
-our $VERSION = '3.49_02';
+our $VERSION = '3.51_01';
 
 =head1 SYNOPSIS
 
@@ -92,7 +92,8 @@ sub can_handle {
     return 0.8 if $file->{lc_ext} eq '.t';    # vote higher than Executable
     return 0.9 if $file->{lc_ext} eq '.pl';
 
-    return 0.75 if $file->{dir} =~ /^t\b/;    # vote higher than Executable
+    my @dirs = File::Spec->splitdir($file->{dir});
+    return 0.75 if scalar(@dirs) && $dirs[0] eq 't';    # vote higher than Executable
 
     # backwards compat, always vote:
     return 0.25;
